@@ -9,20 +9,31 @@
 # See LICENSE.txt for more info.
 # -----------------------------------------------------------------------------
 
-__all__ = ["install",
-           "load_ipython_extension", "unload_ipython_extension",
-           "init_ipython", "load_config", "run", "run_qt",
-           "get_python_version", "get_ipython_version",
-           "get_pytango_version"]
+__all__ = [
+    "install",
+    "load_ipython_extension",
+    "unload_ipython_extension",
+    "init_ipython",
+    "load_config",
+    "run",
+    "run_qt",
+    "get_python_version",
+    "get_ipython_version",
+    "get_pytango_version",
+]
 
 try:
     from ._version import version as __version__
 except ImportError:
     __version__ = "0.0+unknown"
 
-from .common import get_python_version, get_ipython_version
-from .common import get_pytango_version
-
+from .common import get_ipython_version, get_pytango_version, get_python_version
 from .install import install
-from .itango import load_ipython_extension, unload_ipython_extension
-from .itango import init_ipython, load_config, run, run_qt
+from .itango import (
+    init_ipython,
+    load_config,
+    load_ipython_extension,
+    run,
+    run_qt,
+    unload_ipython_extension,
+)
