@@ -13,41 +13,50 @@
 
 from __future__ import print_function
 
-__all__ = ["load_config", "load_ipython_extension", "unload_ipython_extension",
-           "run", "run_qt"]
+__all__ = [
+    "load_config",
+    "load_ipython_extension",
+    "unload_ipython_extension",
+    "run",
+    "run_qt",
+]
 
+import io
+import operator
 import os
 import re
-import io
 import sys
-import operator
 import textwrap
 
-import IPython
-from IPython.core.error import UsageError
-from IPython.utils.ipstruct import Struct
-from IPython.core.page import page
-from IPython.core.interactiveshell import InteractiveShell
-from IPython.terminal.ipapp import launch_new_instance
-from packaging.version import Version
-from traitlets.config.application import Application
-
 import tango
 import tango.utils
+from IPython.core.error import UsageError
+from IPython.core.interactiveshell import InteractiveShell
+from IPython.core.page import page
+from IPython.terminal.ipapp import launch_new_instance
+from IPython.utils.ipstruct import Struct
+from traitlets.config.application import Application
 
-from . import __version__
-from . import common
+from . import __version__, common
 from .eventlogger import EventLogger
-from .install import install, is_installed, install_kernel
+from .install import install, install_kernel, is_installed
 
-
-_TG_EXCEPTIONS = tango.DevFailed, tango.ConnectionFailed, \
-    tango.CommunicationFailed, \
-    tango.NamedDevFailed, tango.NamedDevFailedList, \
-    tango.WrongNameSyntax, tango.NonDbDevice, tango.WrongData, \
-    tango.NonSupportedFeature, tango.AsynCall, \
-    tango.AsynReplyNotArrived, tango.EventSystemFailed, \
-    tango.DeviceUnlocked, tango.NotAllowed
+_TG_EXCEPTIONS = (
+    tango.DevFailed,
+    tango.ConnectionFailed,
+    tango.CommunicationFailed,
+    tango.NamedDevFailed,
+    tango.NamedDevFailedList,
+    tango.WrongNameSyntax,
+    tango.NonDbDevice,
+    tango.WrongData,
+    tango.NonSupportedFeature,
+    tango.AsynCall,
+    tango.AsynReplyNotArrived,
+    tango.EventSystemFailed,
+    tango.DeviceUnlocked,
+    tango.NotAllowed,
+)
 
 _DB_SYMB = "db"
 _DFT_TANGO_HOST = None
@@ -57,23 +66,9 @@ _PYTHON_ERR = "__python_error"
 _tango_init = False
 
 
-def _get_ipython_major_version():
-    ver = None
-    if hasattr(IPython, "Release"):
-        ver = IPython.Release.version.split(".")
-    elif hasattr(IPython, "release"):
-        ver = IPython.release.version.split(".")
-    return int(ver[0]) if ver else 0
-
-
-if _get_ipython_major_version() >= 5:
-    _DEFAULTCOLOR = 'Neutral'
-else:
-    _DEFAULTCOLOR = 'Linux'
-
-
 # IPython utilities
 
+
 def get_pylab_mode():
     return get_app().pylab
 
@@ -86,11 +81,6 @@ def get_app():
     return Application.instance()
 
 
-def get_shell():
-    """Get the global InteractiveShell instance."""
-    return get_app().shell
-
-
 def get_ipapi():
     """Get the global InteractiveShell instance."""
     return InteractiveShell.instance()
@@ -105,12 +95,12 @@ def get_editor():
 
 
 def get_user_ns():
-    return get_shell().user_ns
+    return get_ipapi().user_ns
 
 
 class DeviceClassCompleter(object):
     """Completer class that returns the list of devices of some class when
-    called. """
+    called."""
 
     def __init__(self, klass, devices):
         self._klass = klass
@@ -137,6 +127,7 @@ class DeviceClassCompleter(object):
 
 # Completers
 
+
 def __DeviceProxy_completer(ip, evt):
     db = __get_db()
     if db is None:
@@ -191,21 +182,21 @@ def __AttributeProxy_completer(ip, evt):
     if n == 0:
         # means it can be an attr alias, a device name has alias or as full device name
         ret = list(cache.get("attr_aliases").keys())
-        ret.extend([ d+"/" for d in devs ])
-        ret.extend([ d+"/" for d in dev_aliases ])
+        ret.extend([d + "/" for d in devs])
+        ret.extend([d + "/" for d in dev_aliases])
         # device alias found!
         if symb in dev_alias_list:
             dev_name = symb
     elif n == 1:
         # it can still be a full device name
-        ret = [ d+"/" for d in devs ]
+        ret = [d + "/" for d in devs]
         # it can also be devalias/attr_name
         dev, attr = symb.split("/")
         if dev in dev_alias_list:
             dev_name = dev
     elif n == 2:
         # it is for sure NOT an attribute alias or a device alias
-        ret = [ d+"/" for d in devs ]
+        ret = [d + "/" for d in devs]
         # device found!
         if symb in dev_list:
             dev_name = symb
@@ -225,8 +216,8 @@ def __AttributeProxy_completer(ip, evt):
             d._attr_list = d.get_attribute_list()
         if ret is None:
             ret = []
-        ret.extend([ "%s/%s" % (dev_name, a) for a in d._attr_list ])
-    except:
+        ret.extend(["%s/%s" % (dev_name, a) for a in d._attr_list])
+    except Exception:
         # either DeviceProxy could not be created or device is not online
         pass
 
@@ -249,7 +240,7 @@ def __get_device_proxy(dev_name):
         if d is None:
             try:
                 d = data[3] = tango.DeviceProxy(dev_name)
-            except:
+            except Exception:
                 pass
         return d
 
@@ -268,15 +259,18 @@ def __get_device_subscriptions(dev_name):
     if data is not None:
         return data[4]
 
+
 __monitor_completer = __AttributeProxy_completer
 
 
 # Magic commands
 
-def refreshdb(self, parameter_s=''):
+
+def refreshdb(self, parameter_s=""):
     init_db(parameter_s)
 
-def switchdb(self, parameter_s=''):
+
+def switchdb(self, parameter_s=""):
     """Switches the active tango Database.
 
     Usage: switchdb <host>[(:| )<port>]
@@ -288,13 +282,14 @@ def switchdb(self, parameter_s=''):
     In [2]: switchdb homer 10005
     In [3]: switchdb homer"""
 
-    if parameter_s == '':
-        raise UsageError("%switchdb: Must specify a tango database name. "
-                         "See '%switchdb?'")
+    if parameter_s == "":
+        raise UsageError(
+            "%switchdb: Must specify a tango database name. See '%switchdb?'"
+        )
     return init_db(parameter_s)
 
 
-def lsdev(self, parameter_s=''):
+def lsdev(self, parameter_s=""):
     """Lists all known tango devices.
 
     Usage: lsdev [<device name filter(regular expression)]
@@ -320,7 +315,7 @@ def lsdev(self, parameter_s=''):
     templ = "{0:{l[0]}} {1:{l[1]}} {2:{l[2]}} {3:{l[3]}}"
     msg = templ.format(*title, l=lengths)
     print(msg, file=s)
-    print(*map(operator.mul, lengths, len(lengths)*"-"), file=s)
+    print(*map(operator.mul, lengths, len(lengths) * "-"), file=s)
     for d, v in data.items():
         if reg_exp and not reg_exp.match(d):
             continue
@@ -329,7 +324,7 @@ def lsdev(self, parameter_s=''):
     page(s.read())
 
 
-def lsdevclass(self, parameter_s=''):
+def lsdevclass(self, parameter_s=""):
     """Lists all known tango device classes.
 
     Usage: lsdevclass [<class name filter(regular expression)]
@@ -349,12 +344,14 @@ def lsdevclass(self, parameter_s=''):
         return
     data = db._db_cache.klasses
 
-    data = [ "%-030s" % klass for klass in data.keys() if not reg_exp or reg_exp.match(klass) ]
+    data = [
+        "%-030s" % klass for klass in data.keys() if not reg_exp or reg_exp.match(klass)
+    ]
     s = textwrap.fill(" ".join(data), 80)
     page(s)
 
 
-def lsserv(self, parameter_s=''):
+def lsserv(self, parameter_s=""):
     """Lists all known tango servers.
 
     Usage: lsserv [<class name filter(regular expression)]
@@ -374,12 +371,16 @@ def lsserv(self, parameter_s=''):
         return
     data = db._db_cache.servers
 
-    data = [ "%-030s" % server for server in data.keys() if not reg_exp or reg_exp.match(server) ]
+    data = [
+        "%-030s" % server
+        for server in data.keys()
+        if not reg_exp or reg_exp.match(server)
+    ]
     s = textwrap.fill(" ".join(data), 80)
     page(s)
 
 
-def tango_error(self, parameter_s=''):
+def tango_error(self, parameter_s=""):
     """Displays detailed information about the last tango error"""
     global _TANGO_ERR
     err_info = get_user_ns().get(_TANGO_ERR)
@@ -390,7 +391,7 @@ def tango_error(self, parameter_s=''):
     print(err_info[1])
 
 
-def python_error(self, parameter_s=''):
+def python_error(self, parameter_s=""):
     """Displays detailed information about the last python error"""
     global _PYTHON_ERR
     err_info = get_user_ns().get(_PYTHON_ERR)
@@ -401,6 +402,7 @@ def python_error(self, parameter_s=''):
     etype, evalue, etb = err_info[:3]
     ip.InteractiveTB(etype=etype, evalue=evalue, etb=etb, tb_offset=None)
 
+
 _EVT_LOG = None
 
 
@@ -411,7 +413,7 @@ def __get_event_log():
     return _EVT_LOG
 
 
-def mon(self, parameter_s=''):
+def mon(self, parameter_s=""):
     """Monitor a given attribute.
 
     %mon -a <attribute name>           - activates monitoring of given attribute
@@ -428,14 +430,14 @@ def mon(self, parameter_s=''):
 
     # make sure parameter_s is a str and not a unicode
     parameter_s = str(parameter_s)
-    opts, args = self.parse_options(parameter_s,'adril', mode='list')
+    opts, args = self.parse_options(parameter_s, "adril", mode="list")
     if len(args) > 3:
         raise UsageError("%mon: too many arguments")
-    if 'd' in opts:
+    if "d" in opts:
         try:
             todel = args[0]
-        except IndexError:
-            raise UsageError("%mon -d: must provide an attribute to unmonitor")
+        except IndexError as err:
+            raise UsageError("%mon -d: must provide an attribute to unmonitor") from err
         else:
             try:
                 dev, _, attr = todel.rpartition("/")
@@ -445,14 +447,14 @@ def mon(self, parameter_s=''):
                 d = __get_device_proxy(dev)
                 d.unsubscribe_event(attr_id)
                 print("Stopped monitoring '%s'" % todel)
-            except KeyError:
-                raise UsageError("%%mon -d: Not monitoring '%s'" % todel)
+            except KeyError as err:
+                raise UsageError("%%mon -d: Not monitoring '%s'" % todel) from err
 
-    elif 'a' in opts:
+    elif "a" in opts:
         try:
             toadd = args[0]
-        except IndexError:
-            raise UsageError("%mon -a: must provide an attribute to monitor")
+        except IndexError as err:
+            raise UsageError("%mon -a: must provide an attribute to monitor") from err
         dev, _, attr = toadd.rpartition("/")
         subscriptions = __get_device_subscriptions(dev)
         attr_id = subscriptions.get(attr.lower())
@@ -461,23 +463,22 @@ def mon(self, parameter_s=''):
         d = __get_device_proxy(dev)
         w = __get_event_log()
         model = w.model()
-        attr_id = d.subscribe_event(attr, tango.EventType.CHANGE_EVENT,
-                                    model, [])
+        attr_id = d.subscribe_event(attr, tango.EventType.CHANGE_EVENT, model, [])
         subscriptions[attr.lower()] = attr_id
         print("'%s' is now being monitored. Type 'mon' to see all events" % toadd)
-    elif 'r' in opts:
+    elif "r" in opts:
         for d, v in db._db_cache.devices.items():
             d, subs = v[3], v[4]
             for _id in subs.values():
                 d.unsubscribe_event(_id)
             v[4] = {}
-    elif 'i' in opts:
+    elif "i" in opts:
         try:
             evtid = int(args[0])
-        except IndexError:
-            raise UsageError("%mon -i: must provide an event ID")
-        except ValueError:
-            raise UsageError("%mon -i: must provide a valid event ID")
+        except IndexError as err:
+            raise UsageError("%mon -i: must provide an event ID") from err
+        except ValueError as err:
+            raise UsageError("%mon -i: must provide a valid event ID") from err
         try:
             w = __get_event_log()
             e = w.getEvents()[evtid]
@@ -485,15 +486,16 @@ def mon(self, parameter_s=''):
                 print(str(tango.DevFailed(*e.errors)))
             else:
                 print(str(e))
-        except IndexError:
-            raise UsageError("%mon -i: must provide a valid event ID")
-    elif 'l' in opts:
+        except IndexError as err:
+            raise UsageError("%mon -i: must provide a valid event ID") from err
+    elif "l" in opts:
         try:
             dexpr = args[0]
             aexpr = args[1]
-        except IndexError:
-            raise UsageError("%mon -l: must provide valid device and " \
-                             "attribute filters")
+        except IndexError as err:
+            raise UsageError(
+                "%mon -l: must provide valid device and attribute filters"
+            ) from err
         w = __get_event_log()
         w.show(dexpr, aexpr)
     else:
@@ -504,6 +506,7 @@ def mon(self, parameter_s=''):
 # Useful functions
 # (not magic commands but accessible from CLI as normal python functions)
 
+
 def get_device_map():
     """Returns a dictionary where keys are device names and value is a sequence
     of 4 elements:
@@ -539,6 +542,7 @@ def get_class_map():
         return
     return db._db_cache.klasses
 
+
 def get_alias_map():
     """Returns a dictionary where keys are the tango device aliases and value
     is a the tango device name"""
@@ -571,6 +575,7 @@ def get_alias_list():
 
 # Private helper methods
 
+
 def __exc_handler(ip, etype, value, tb, tb_offset=None):
     global _TG_EXCEPTIONS
     user_ns = get_user_ns()
@@ -579,7 +584,7 @@ def __exc_handler(ip, etype, value, tb, tb_offset=None):
         user_ns[_TANGO_ERR] = etype, value, tb, tb_offset
         if len(value.args):
             v = value.args[0]
-            print("%s: %s" % (v.reason ,v.desc))
+            print("%s: %s" % (v.reason, v.desc))
         else:
             print("Empty DevFailed")
         print("(For more detailed information type: tango_error)")
@@ -596,18 +601,18 @@ def __get_default_tango_host():
         try:
             db = tango.Database()
             _DFT_TANGO_HOST = "%s:%s" % (db.get_db_host(), db.get_db_port())
-        except:
+        except Exception:
             pass
     return _DFT_TANGO_HOST
 
 
 def __get_db(host_port=None):
     """host_port == None: Use current DB whatever it is or create
-                          default if doesn't exist
-       host_port == '' : use default db. If it is not the current db, switch
-                         current db to it and return it
-       host_port == ... : if ... is not the current db, switch current db to it
-                          and return it
+                       default if doesn't exist
+    host_port == '' : use default db. If it is not the current db, switch
+                      current db to it and return it
+    host_port == ... : if ... is not the current db, switch current db to it
+                       and return it
     """
     user_ns = get_user_ns()
 
@@ -617,7 +622,7 @@ def __get_db(host_port=None):
     if host_port is None:
         if db is None:
             host_port = __get_default_tango_host()
-    elif host_port == '':
+    elif host_port == "":
         host_port = __get_default_tango_host()
     else:
         host_port = host_port.strip().replace(" ", ":")
@@ -649,7 +654,9 @@ def __get_db(host_port=None):
                 user_ns["DB_NAME"] = old_host_port
             else:
                 print("\nCould not access any Database. Make sure:")
-                print("\t- .tangorc, /etc/tangorc or TANGO_HOST environment is defined.")
+                print(
+                    "\t- .tangorc, /etc/tangorc or TANGO_HOST environment is defined."
+                )
                 print("\t- the Database DS is running")
                 user_ns["DB_NAME"] = "OFFLINE"
 
@@ -662,10 +669,10 @@ def __get_db(host_port=None):
 def __get_obj_name(o):
     try:
         n = o.__name__
-    except:
+    except Exception:
         try:
             n = o.__class__.__name__
-        except:
+        except Exception:
             n = "<unknown>"
     return n
 
@@ -677,75 +684,24 @@ def __completer_wrapper(f):
         except Exception as e:
             print()
             print("An unexpected exception ocorred during ITango command completer.")
-            print("Please send a bug report to the PyTango team with the following information:")
-            print(80*"-")
-            print("Completer:",__get_obj_name(f))
-            print(80*"-")
+            print(
+                "Please send a bug report to the PyTango team with the following information:"
+            )
+            print(80 * "-")
+            print("Completer:", __get_obj_name(f))
+            print(80 * "-")
             import traceback
+
             traceback.print_exc()
-            print(80*"-")
+            print(80 * "-")
             raise e
+
     return wrapper
 
 
-def __expose_magic(ip, name, fn, completer_func=None):
-    ip.define_magic(name, fn)
-
-    if completer_func is None:
-        return
-
-    # enable macro param completion
-    ip.set_hook('complete_command', completer_func, re_key = ".*" + name)
-
-
-def __unexpose_magic(ip, name):
-    delattr(ip, name)
-
-
-def __build_color_scheme(ip, name):
-    import IPython.Prompts
-    import IPython.PyColorize
-    import IPython.excolors
-    from IPython.utils.coloransi import TermColors, InputTermColors
-
-    # make some schemes as instances so we can copy them for modification easily:
-    PromptColors = IPython.Prompts.PromptColors
-    ANSICodeColors = IPython.PyColorize.ANSICodeColors
-    ExceptionColors = IPython.excolors.ExceptionColors
-    TBColors = ip.IP.InteractiveTB.color_scheme_table
-    SyntaxColors = ip.IP.SyntaxTB.color_scheme_table
-    InspectColors = IPython.OInspect.InspectColors
-
-    promptTangoColors = PromptColors[_DEFAULTCOLOR].copy(name)
-    ANSITangoColors = ANSICodeColors[_DEFAULTCOLOR].copy(name)
-    exceptionTangoColors = ExceptionColors[_DEFAULTCOLOR].copy(name)
-    TBTangoColors = TBColors[_DEFAULTCOLOR].copy(name)
-    syntaxTangoColors = SyntaxColors[_DEFAULTCOLOR].copy(name)
-    inspectTangoColors = InspectColors[_DEFAULTCOLOR].copy(name)
-
-    # initialize prompt with default tango colors
-    promptTangoColors.colors.in_prompt  = InputTermColors.Purple
-    promptTangoColors.colors.in_number  = InputTermColors.LightPurple
-    promptTangoColors.colors.in_prompt2 = InputTermColors.Purple
-    promptTangoColors.colors.out_prompt = TermColors.Blue
-    promptTangoColors.colors.out_number = TermColors.LightBlue
-
-    ret= { "prompt" : (PromptColors, promptTangoColors),
-          "ANSI"   : (ANSICodeColors, ANSITangoColors),
-          "except" : (ExceptionColors, exceptionTangoColors),
-          "TB"     : (TBColors, TBTangoColors),
-          "Syntax" : (SyntaxColors, syntaxTangoColors),
-          "Inspect": (InspectColors, inspectTangoColors) }
-
-    if ip.IP.isthreaded:
-        TBThreadedColors = ip.IP.sys_excepthook.color_scheme_table
-        TBThreadedTangoColors = TBThreadedColors[_DEFAULTCOLOR].copy(name)
-        ret["TBThreaded"] = TBThreadedColors, TBThreadedTangoColors
-    return ret
-
-
 # Initialization methods
 
+
 def init_pytango(ip):
     """Initializes the IPython environment with PyTango elements"""
 
@@ -758,15 +714,15 @@ def init_pytango(ip):
     # add completers
     dp_completer = __completer_wrapper(__DeviceProxy_completer)
     attr_completer = __completer_wrapper(__AttributeProxy_completer)
-    ip.set_hook('complete_command', dp_completer, re_key = r".*DeviceProxy[^\w\.]+")
-    ip.set_hook('complete_command', dp_completer, re_key = r".*Device[^\w\.]+")
-    ip.set_hook('complete_command', attr_completer, re_key = r".*AttributeProxy[^\w\.]+")
-    ip.set_hook('complete_command', attr_completer, re_key = r".*Attribute[^\w\.]+")
+    ip.set_hook("complete_command", dp_completer, re_key=r".*DeviceProxy[^\w\.]+")
+    ip.set_hook("complete_command", dp_completer, re_key=r".*Device[^\w\.]+")
+    ip.set_hook("complete_command", attr_completer, re_key=r".*AttributeProxy[^\w\.]+")
+    ip.set_hook("complete_command", attr_completer, re_key=r".*Attribute[^\w\.]+")
 
     ip.set_custom_exc((Exception,), __exc_handler)
 
 
-def init_db(parameter_s=''):
+def init_db(parameter_s=""):
     ip = get_ipapi()
     user_ns = get_user_ns()
     global _DB_SYMB
@@ -803,10 +759,12 @@ def init_db(parameter_s=''):
         dev_lower = device.lower()
 
         # hide dserver devices
-        if dev_lower.startswith("dserver/"): continue
+        if dev_lower.startswith("dserver/"):
+            continue
 
         # hide alias that start with "_"
-        if alias and alias[0] == "_": alias = ''
+        if alias and alias[0] == "_":
+            alias = ""
 
         # last None below is to be filled by DeviceProxy object on demand
         # last empty dict<str, int> where keys is attribute name and value is
@@ -826,14 +784,14 @@ def init_db(parameter_s=''):
             klass_devs.append(alias)
 
     exposed_klasses = {}
-    excluded_klasses = "DServer",
+    excluded_klasses = ("DServer",)
     for klass, devices in klass_dict.items():
         if klass in excluded_klasses:
             continue
         exists = klass in user_ns
         if not exists or klass in old_junk:
             c = DeviceClassCompleter(klass, devices)
-            ip.set_hook('complete_command', c, re_key = r".*" + klass + r"[^\w\.]+")
+            ip.set_hook("complete_command", c, re_key=r".*" + klass + r"[^\w\.]+")
             exposed_klasses[klass] = tango.DeviceProxy
 
     # expose classes no user namespace
@@ -858,58 +816,50 @@ def init_db(parameter_s=''):
     attr_alias_list = tango.utils.CaselessList(attr_alias_dict.keys())
 
     # Build cache
-    db_cache = Struct(devices=dev_dict, aliases=alias_dict,
-        servers=serv_dict, klasses=klass_dict, junk=exposed_klasses,
-        attr_aliases=attr_alias_dict, device_list=device_list,
-        alias_list=alias_list, attr_alias_list=attr_alias_list)
+    db_cache = Struct(
+        devices=dev_dict,
+        aliases=alias_dict,
+        servers=serv_dict,
+        klasses=klass_dict,
+        junk=exposed_klasses,
+        attr_aliases=attr_alias_dict,
+        device_list=device_list,
+        alias_list=alias_list,
+        attr_alias_list=attr_alias_list,
+    )
 
     db._db_cache = db_cache
 
-    # Add this DB to the list of known DBs (for possible use in magic commands)
-    if db.get_db_port_num() == 10000:
-        db_name = db.get_db_host()
-    else:
-        db_name = "%s:%s" % (db.get_db_host(), db.get_db_port())
     return db
 
 
 def init_magic(ip):
-
     import IPython.core.magic
 
-    new_style_magics = hasattr(IPython.core.magic, 'Magics') and hasattr(IPython.core.magic, 'magics_class')
+    @IPython.core.magic.magics_class
+    class Tango(IPython.core.magic.Magics):
+        refreshdb = IPython.core.magic.line_magic(refreshdb)
+        switchdb = IPython.core.magic.line_magic(switchdb)
+        lsdev = IPython.core.magic.line_magic(lsdev)
+        lsdevclass = IPython.core.magic.line_magic(lsdevclass)
+        lsserv = IPython.core.magic.line_magic(lsserv)
+        tango_error = IPython.core.magic.line_magic(tango_error)
+        python_error = IPython.core.magic.line_magic(python_error)
+        mon = IPython.core.magic.line_magic(mon)
 
-    if new_style_magics:
-        @IPython.core.magic.magics_class
-        class Tango(IPython.core.magic.Magics):
+    ip.register_magics(Tango)
+    ip.set_hook("complete_command", __monitor_completer, re_key=".*" + "mon")
 
-            refreshdb = IPython.core.magic.line_magic(refreshdb)
-            switchdb = IPython.core.magic.line_magic(switchdb)
-            lsdev = IPython.core.magic.line_magic(lsdev)
-            lsdevclass = IPython.core.magic.line_magic(lsdevclass)
-            lsserv = IPython.core.magic.line_magic(lsserv)
-            tango_error = IPython.core.magic.line_magic(tango_error)
-            python_error = IPython.core.magic.line_magic(python_error)
-            mon = IPython.core.magic.line_magic(mon)
-
-        ip.register_magics(Tango)
-        ip.set_hook('complete_command', __monitor_completer, re_key = ".*" + "mon")
-    else:
-        __expose_magic(ip, "refreshdb", refreshdb)
-        __expose_magic(ip, "switchdb", switchdb)
-        __expose_magic(ip, "lsdev", lsdev)
-        __expose_magic(ip, "lsdevclass", lsdevclass)
-        __expose_magic(ip, "lsserv", lsserv)
-        __expose_magic(ip, "tango_error", tango_error)
-        __expose_magic(ip, "python_error", python_error)
-        __expose_magic(ip, "mon", mon, __monitor_completer)
-
-    get_user_ns().update({"get_device_map"   : get_device_map,
-                   "get_server_map"  : get_server_map,
-                   "get_class_map"   : get_class_map,
-                   "get_alias_map"   : get_alias_map,
-                   "get_device_list" : get_device_list,
-                   "get_alias_list"  : get_alias_list})
+    get_user_ns().update(
+        {
+            "get_device_map": get_device_map,
+            "get_server_map": get_server_map,
+            "get_class_map": get_class_map,
+            "get_alias_map": get_alias_map,
+            "get_device_list": get_device_list,
+            "get_alias_list": get_alias_list,
+        }
+    )
 
 
 def complete(text):
@@ -927,23 +877,26 @@ def complete(text):
     outcomps = sorted(comps)
     return outcomps
 
+
 __DIRNAME = os.path.dirname(os.path.abspath(__file__))
-__RES_DIR = os.path.join(__DIRNAME, 'resource')
+__RES_DIR = os.path.join(__DIRNAME, "resource")
 
 
 class __TangoDeviceInfo(object):
-    """Helper class for when DeviceProxy.info() is not available"""
+    """Helper class for when DeviceProxy.info() is not available (device not exported)"""
 
     def __init__(self, dev):
         try:
             db = dev.get_device_db()
             klass = db.get_class_for_device(dev.dev_name())
             self.dev_class = self.dev_type = klass
-        except:
-            self.dev_class = self.dev_type = 'Device'
-        self.doc_url = 'http://www.esrf.eu/computing/cs/tango/tango_doc/ds_doc/index.html'
-        self.server_host = 'Unknown'
-        self.server_id = 'Unknown'
+        except Exception:
+            self.dev_class = self.dev_type = "Device"
+        self.doc_url = (
+            "http://www.esrf.eu/computing/cs/tango/tango_doc/ds_doc/index.html"
+        )
+        self.server_host = "Unknown"
+        self.server_id = "Unknown"
         self.server_version = 1
 
 
@@ -956,7 +909,7 @@ def __get_device_class_icon(klass="Device"):
             icon_filename = icon_filename[0]
         else:
             icon_filename = klass.lower() + os.path.extsep + "png"
-    except:
+    except Exception:
         icon_filename = klass.lower() + os.path.extsep + "png"
 
     if os.path.isabs(icon_filename):
@@ -993,21 +946,25 @@ def display_deviceclass_html(dev_class):
     db = __get_db()
     try:
         fmt["database"] = db.get_db_host() + ":" + db.get_db_port()
-    except:
+    except Exception:
         try:
             fmt["database"] = db.get_file_name()
-        except:
-            fmt["database"]  = "Unknown"
+        except Exception:
+            fmt["database"] = "Unknown"
 
     doc_url = __get_class_property_str(dev_class, "doc_url", "www.tango-controls.org")
     try:
-        fmt["doc_url"] = doc_url[doc_url.index("http"):]
+        fmt["doc_url"] = doc_url[doc_url.index("http") :]
     except ValueError:
         fmt["doc_url"] = doc_url
 
-    fmt['icon'] = __get_device_class_icon(dev_class)
-    fmt['super_class'] = __get_class_property_str(dev_class, "InheritedFrom", "DeviceImpl")
-    fmt['description'] = __get_class_property_str(dev_class, "Description", "A Tango device class")
+    fmt["icon"] = __get_device_class_icon(dev_class)
+    fmt["super_class"] = __get_class_property_str(
+        dev_class, "InheritedFrom", "DeviceImpl"
+    )
+    fmt["description"] = __get_class_property_str(
+        dev_class, "Description", "A Tango device class"
+    )
     return __DEV_CLASS_HTML_TEMPLATE.format(**fmt)
 
 
@@ -1024,7 +981,7 @@ def __get_device_icon(dev_proxy, klass="Device"):
                 icon_filename = icon_filename[0]
             else:
                 icon_filename = klass.lower() + os.path.extsep + "png"
-    except:
+    except Exception:
         icon_filename = klass.lower() + os.path.extsep + "png"
 
     if os.path.isabs(icon_filename):
@@ -1035,6 +992,7 @@ def __get_device_icon(dev_proxy, klass="Device"):
         icon = os.path.join(__RES_DIR, "device.png")
     return icon
 
+
 __DEV_HTML_TEMPLATE = """\
 <table border="0" cellpadding="2" width="100%">
 <tr><td width="140" rowspan="7" valign="middle" align="center"><img src="{icon}" height="128"/></td>
@@ -1052,36 +1010,41 @@ def display_deviceproxy_html(dev_proxy):
     """displayhook function for tango.DeviceProxy, rendered as HTML"""
     try:
         info = dev_proxy.info()
-    except:
+    except Exception:
         info = __TangoDeviceInfo(dev_proxy)
     name = dev_proxy.dev_name()
-    fmt = dict(dev_class=info.dev_class, server_id=info.server_id,
-               server_host=info.server_host, name=name)
+    fmt = dict(
+        dev_class=info.dev_class,
+        server_id=info.server_id,
+        server_host=info.server_host,
+        name=name,
+    )
 
     try:
         fmt["alias"] = dev_proxy.alias()
-    except:
+    except Exception:
         fmt["alias"] = "-----"
 
     db = dev_proxy.get_device_db()
     try:
         fmt["database"] = db.get_db_host() + ":" + db.get_db_port()
-    except:
+    except Exception:
         try:
             fmt["database"] = db.get_file_name()
-        except:
-            fmt["database"]  = "Unknown"
+        except Exception:
+            fmt["database"] = "Unknown"
 
     doc_url = info.doc_url.split("\n")[0]
     try:
-        fmt["doc_url"] = doc_url[doc_url.index("http"):]
+        fmt["doc_url"] = doc_url[doc_url.index("http") :]
     except ValueError:
         fmt["doc_url"] = doc_url
 
-    fmt['icon'] = __get_device_icon(dev_proxy, info.dev_class)
+    fmt["icon"] = __get_device_icon(dev_proxy, info.dev_class)
 
     return __DEV_HTML_TEMPLATE.format(**fmt)
 
+
 __DB_HTML_TEMPLATE = """\
 <table border="0" cellpadding="2" width="100%">
 <tr><td width="140" rowspan="2" valign="middle" align="center"><img src="{icon}" height="128"/></td>
@@ -1096,21 +1059,22 @@ def display_database_html(db):
 
     try:
         fmt["name"] = db.get_db_host() + ":" + db.get_db_port()
-    except:
+    except Exception:
         try:
             fmt["name"] = db.get_file_name()
-        except:
-            fmt["name"]  = "Unknown"
+        except Exception:
+            fmt["name"] = "Unknown"
 
     try:
         fmt["info"] = db.get_info().replace("\n", "<BR/>")
-    except:
+    except Exception:
         fmt["info"] = "Unknown"
 
-    fmt['icon'] = os.path.join(__RES_DIR, "database.png")
+    fmt["icon"] = os.path.join(__RES_DIR, "database.png")
 
     return __DB_HTML_TEMPLATE.format(**fmt)
 
+
 __DEV_ATTR_RW_HTML_TEMPLATE = """\
 <table border="0" cellpadding="2" width="100%">
 <tr><td colspan="2" bgcolor="{bgcolor}">{name} ({type}, {data_format}, {quality}) at {time}</td></tr>
@@ -1148,7 +1112,7 @@ def display_deviceattribute_html(da):
     fmt = dict(name=da.name, type=da.type, data_format=da.data_format)
     template = None
     if da.has_failed:
-        fmt['error'] = "\n".join(map(str, da.get_err_stack())).replace("\n", "<br/>")
+        fmt["error"] = "\n".join(map(str, da.get_err_stack())).replace("\n", "<br/>")
 
         template = __DEV_ATTR_ERR_HTML_TEMPLATE
     else:
@@ -1157,21 +1121,22 @@ def display_deviceattribute_html(da):
             template = __DEV_ATTR_RO_HTML_TEMPLATE
         else:
             template = __DEV_ATTR_RW_HTML_TEMPLATE
-            fmt['w_value'] = str(da.w_value)
+            fmt["w_value"] = str(da.w_value)
             if da.data_format == tango.AttrDataFormat.SCALAR:
-                fmt['w_dim'] = ""
+                fmt["w_dim"] = ""
             else:
-                fmt['w_dim'] = "<br/>(%d, %d)" % (wd.dim_x, wd.dim_y)
-        fmt['bgcolor'], fmt['fgcolor'] = QUALITY_TO_HEXCOLOR_STR[da.quality]
-        fmt['quality'] = str(da.quality)
+                fmt["w_dim"] = "<br/>(%d, %d)" % (wd.dim_x, wd.dim_y)
+        fmt["bgcolor"], fmt["fgcolor"] = QUALITY_TO_HEXCOLOR_STR[da.quality]
+        fmt["quality"] = str(da.quality)
         if da.data_format == tango.AttrDataFormat.SCALAR:
-            fmt['r_dim'] = ""
+            fmt["r_dim"] = ""
         else:
-            fmt['r_dim'] = "<br/>(%d, %d)" % (rd.dim_x, rd.dim_y)
-        fmt['value'] = str(da.value)
-        fmt['time'] = str(da.time.todatetime())
+            fmt["r_dim"] = "<br/>(%d, %d)" % (rd.dim_x, rd.dim_y)
+        fmt["value"] = str(da.value)
+        fmt["time"] = str(da.time.todatetime())
     return template.format(**fmt)
 
+
 __GROUP_HTML_TEMPLATE = """\
 <table border="0" cellpadding="2" width="100%">
 <tr><td width="100" bgcolor="#EEEEEE">Name:</td><td bgcolor="#EEEEEE">{name}</td></tr>
@@ -1183,9 +1148,10 @@ __GROUP_HTML_TEMPLATE = """\
 def display_group_html(group):
     devices = group.get_device_list()
     devices = ", ".join(devices)
-    fmt=dict(name=group.get_name(), size=group.get_size(), devices=devices)
+    fmt = dict(name=group.get_name(), size=group.get_size(), devices=devices)
     return __GROUP_HTML_TEMPLATE.format(**fmt)
 
+
 __GROUP_REPLY_HTML_TEMPLATE = """\
 <table border="0" cellpadding="2" width="100%">
 <tr><td bgcolor="#EEEEEE">{name}</td></tr>
@@ -1203,7 +1169,7 @@ def display_groupreply_html(gr):
     fmt = dict(name="%s/%s" % (gr.dev_name(), gr.obj_name()))
     template = None
     if gr.has_failed():
-        fmt['error'] = "\n".join(map(str, gr.get_err_stack())).replace("\n", "<br/>")
+        fmt["error"] = "\n".join(map(str, gr.get_err_stack())).replace("\n", "<br/>")
         template = __GROUP_REPLY_ERR_HTML_TEMPLATE
     else:
         template = __GROUP_REPLY_HTML_TEMPLATE
@@ -1226,14 +1192,15 @@ def init_display(ip):
     html_formatter.for_type(tango.GroupCmdReply, display_groupreply_html)
 
 
-def init_ipython(ip=None, store=True, pytango=True, colors=True, console=True,
-                 magic=True):
-
+def init_ipython(
+    ip=None, store=True, pytango=True, colors=True, console=True, magic=True
+):
     if ip is None:
         ip = get_ipapi()
 
     global _tango_init
-    if _tango_init is True: return
+    if _tango_init is True:
+        return
 
     init_display(ip)
 
@@ -1249,20 +1216,20 @@ def init_ipython(ip=None, store=True, pytango=True, colors=True, console=True,
 
 
 def load_config(config):
-    import IPython.utils.coloransi
-
     d = {
         "version": __version__,
         "pyver": str(common.get_python_version()),
         "ipyver": str(common.get_ipython_version()),
-        "pytangover": str(common.get_pytango_version())
+        "pytangover": str(common.get_pytango_version()),
+        "Purple": "\033[0;35m",
+        "Blue": "\033[0;34m",
+        "LightBlue": "\033[1;34m",
+        "Normal": "\033[0m",
     }
-    d.update(IPython.utils.coloransi.TermColors.__dict__)
 
-    so = Struct(
-        tango_banner="""%(Blue)shint: Try typing: mydev = Device("%(LightBlue)s<tab>%(Normal)s\n""")
-
-    so = config.get("tango_options", so)
+    tango_banner = (
+        """{Blue}hint: Try typing: mydev = Device("{LightBlue}<tab>{Normal}\n"""
+    )
 
     # ------------------------------------
     # Application
@@ -1274,23 +1241,14 @@ def load_config(config):
     # InteractiveShell
     # ------------------------------------
     i_shell = config.InteractiveShell
-    i_shell.colors = _DEFAULTCOLOR
-
-    # ------------------------------------
-    # PromptManager (ipython >= 0.12)
-    # ------------------------------------
-
-    if common.get_ipython_version() < Version('5.0'):
-        prompt = config.PromptManager
-        prompt.in_template = 'ITango [\\#]: '
-        prompt.out_template = 'Result [\\#]: '
+    i_shell.colors = "Neutral"
 
     # ------------------------------------
     # InteractiveShellApp
     # ------------------------------------
     i_shell_app = config.InteractiveShellApp
-    extensions = getattr(i_shell_app, 'extensions', [])
-    extensions.append('itango')
+    extensions = getattr(i_shell_app, "extensions", [])
+    extensions.append("itango")
     i_shell_app.extensions = extensions
 
     # ------------------------------------
@@ -1298,35 +1256,27 @@ def load_config(config):
     # ------------------------------------
     term_app = config.TerminalIPythonApp
     term_app.display_banner = True
-    #term_app.nosep = False
-    #term_app.classic = True
 
     # ------------------------------------
-    # IPKernelApp: options for the  Qt Console
+    # IPythonWidget (QtConsole)
     # ------------------------------------
-    #kernel_app = config.IPKernelApp
     ipython_widget = config.IPythonWidget
-    ipython_widget.in_prompt  = 'ITango [<span class="in-prompt-number">%i</span>]: '
+    ipython_widget.in_prompt = 'ITango [<span class="in-prompt-number">%i</span>]: '
     ipython_widget.out_prompt = 'Result [<span class="out-prompt-number">%i</span>]: '
 
-    #zmq_i_shell = config.ZMQInteractiveShell
-
     # ------------------------------------
     # TerminalInteractiveShell
     # ------------------------------------
     term_i_shell = config.TerminalInteractiveShell
     banner = """\
-%(Purple)sITango %(version)s%(Normal)s -- An interactive %(Purple)sTango%(Normal)s client.
+{Purple}ITango {version}{Normal} -- An interactive {Purple}Tango{Normal} client.
 
-Running on top of Python %(pyver)s, IPython %(ipyver)s and PyTango %(pytangover)s
+Running on top of Python {pyver}, IPython {ipyver} and PyTango {pytangover}
 
 help      -> ITango's help system.
 object?   -> Details about 'object'. ?object also works, ?? prints more.
-"""
+""".format(**d)
 
-    banner = banner % d
-    banner = banner.format(**d)
-    tango_banner = so.tango_banner % d
     tango_banner = tango_banner.format(**d)
     all_banner = "\n".join((banner, tango_banner))
 
@@ -1350,7 +1300,7 @@ def load_ipython_extension(ipython):
 
 def unload_ipython_extension(ipython):
     # If you want your extension to be unloadable, put that logic here.
-    #print "Unloading tango IPython extension"
+    # print "Unloading tango IPython extension"
     pass
 
 
@@ -1361,11 +1311,9 @@ def patch_qt_console():
     Return the customized application class.
     """
     # Traitlets imports
-    from traitlets import Unicode
-
     # Qt console imports
-    from qtconsole import rich_ipython_widget
-    from qtconsole import qtconsoleapp
+    from qtconsole import qtconsoleapp, rich_ipython_widget
+    from traitlets import Unicode
 
     # Patch widget factory
     try:
@@ -1375,13 +1323,12 @@ def patch_qt_console():
 
     # Custom widget class
     class ITangoConsole(WidgetClass):
-
         banner = Unicode(config=True)
 
         def _banner_default(self):
             config = get_config()
             banner = config.ITangoConsole.banner
-            return banner if isinstance(banner, str) else ''
+            return banner if isinstance(banner, str) else ""
 
     # Patch widget factory
     try:
@@ -1411,15 +1358,15 @@ def run(qt=False):
         return app_class.launch_instance()
 
     # Add tango profile
-    if not any(arg.startswith('--profile=') for arg in argv):
+    if not any(arg.startswith("--profile=") for arg in argv):
         argv.append("--profile=tango")
 
     # Configure qt
     if qt:
         patch_qt_console()
-        if 'qtconsole' not in argv:
-            argv.insert(1, 'qtconsole')
-            argv.append('--pylab=inline')
+        if "qtconsole" not in argv:
+            argv.insert(1, "qtconsole")
+            argv.append("--pylab=inline")
 
     # Run
     launch_new_instance()
